(function ($) {

  /**
   * Custom behavior for the "Save" button.
   */
  Drupal.behaviors.viewsSave = {
    attach: function (context, settings) {
      var $form = $('form.views-save-form', context);
      if (!$form.length) {
        return;
      }

      var $save_button = $('.views-save-button-save', $form);
      $form.after($save_button);
      $save_button.removeClass('element-invisible');
      $save_button.click(views_save_show_popup);

      $form.hide();

      $('a.views-save-cancel', $form).click(views_save_hide_popup);

      Drupal.ajax['edit-submit'].success = views_save_success;
      Drupal.ajax['edit-submit'].dataType = 'xml';

      /**
       * Shows the form as a popup.
       */
      function views_save_show_popup() {
        Drupal.CTools.Modal.show(settings.views_save.modal_settings);
        $('#modal-title').html(settings.views_save.modal_title);
        $('#modal-content').empty().append($form);
        $form.show();

        return false;
      }

      /**
       * Hides the popup.
       */
      function views_save_hide_popup() {
        // If we don't move the form before closing the modal, its set DOM
        // handlers will be removed.
        $form.hide();
        $form.insertAfter($save_button);
        Drupal.CTools.Modal.dismiss();
        return false;
      }

      /**
       * Hides the popup and replaces the "Save" button with its content.
       */
      function views_save_success(response) {
        var content = '';
        for (var i in response) {
          if (response.hasOwnProperty(i) && response[i].command == 'insert' && response[i].data) {
            content += response[i].data;
          }
        }
        var $content = $(content);
        $save_button.hide().after($content);
        Drupal.attachBehaviors($content, settings);
        Drupal.CTools.Modal.dismiss();
      }

    }
  };

  /**
   * Provide the HTML to create the modal dialog.
   */
  Drupal.theme.prototype.ViewsSavePopup = function () {
    return Drupal.settings.views_save.modal_theme;
  };

})(jQuery);
